/*=============================================================================
vitalnix/accdb - User Management Suite - Unified Account Database
usermod.c - Modify a user account
  Copyright (C) Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2003
  -- License restrictions apply (Dual FAL/GPL2).
  -- For details see doc/FAL.txt and doc/GPL2.txt.
=============================================================================*/
#include <errno.h>
#include <popt.h>
#include <stdio.h>
#include <string.h>
#include <accdb.h>

typedef unsigned char byte;

struct {
  char *lname;
} opt;

extern void interactive(const void **);

static int get_options(int *, const char ***);
static int count_args(const char **);

static char *module_path = "*";

//-----------------------------------------------------------------------------
int main(int argc, char **argv) {
  struct accdb_module *db;
  int eax;

  if(!(eax = get_options(&argc, (const char ***)&argv))) { return !eax; }
  opt.lname = *argv;

  if((db = accdb_load(module_path)) == NULL) {
    fprintf(stderr, "Could not load ACCDB back-end module \"%s\": %s\n",
     module_path, strerror(errno));
  }

  db->open(&db->state);
  db->close(db->state);
  accdb_unload(db);
  return !1;
}

//-----------------------------------------------------------------------------
static int count_args(const char **args) {
  int argk = 0;
  while(*args++ != NULL) { ++argk; }
  return argk;
}

static int get_options(int *argc, const char ***argv) {
  static const char *_empty_argv[] = {NULL};
  const struct poptOption options_table[] = {
    POPT_AUTOHELP
    POPT_TABLEEND
  };

  poptContext ctx;
  const char **args;
  int c, argk;

  ctx = poptGetContext(**argv, *argc, *argv, options_table, 0);
  while((c = poptGetNextOpt(ctx)) >= 0);
  if(c < -1) {
    fprintf(stderr, "%s: %s\n", poptBadOption(ctx, 0), poptStrerror(c));
    return 0;
  }

  if((args = poptGetArgs(ctx)) != NULL) {
    argk = count_args(args);
    poptDupArgv(argk, args, argc, argv);
  } else {
    *argc = 0;
    *argv = _empty_argv;
  }

  if(args == NULL || *args == NULL) {
    // loginname is mandatory
    poptPrintUsage(ctx, stderr, 0);
    return 0;
  }

  poptFreeContext(ctx);
  return 1;
}

//==[ End of file ]============================================================
